@@ -23,20 +23,24 @@
 
 // Own includes
 #include "../libmuon/MuonMainWindow.h"
+#include <KService>
 
 class QAbstractItemView;
 class QModelIndex;
 class QSplitter;
 class QStackedWidget;
+class QStandardItem;
 class QStandardItemModel;
 class QTreeView;
 
 class KMessageWidget;
 class KService;
+class KVBox;
 
 class Application;
 class ApplicationBackend;
 class ApplicationLauncher;
+class ProgressView;
 class ViewSwitcher;
 
 enum ViewModelRole {
@@ -49,16 +53,18 @@ enum ViewModelRole {
 };
 
 enum ViewType {
-   /// An invalid value
-   InvalidView = 0,
-   /// A simple ApplicationView that is filterable by status or origin
-   AppView = 1,
-   /// An ApplicationView that has a Categorical homepage
-   CatView = 2,
-   /// A CategoryView showing subcategories
-   SubCatView = 3,
-   /// A view for showing history
-   History = 4
+    /// An invalid value
+    InvalidView = 0,
+    /// A simple ApplicationView that is filterable by status or origin
+    AppView,
+    /// An ApplicationView that has a Categorical homepage
+    CatView,
+    /// A CategoryView showing subcategories
+    SubCatView,
+    /// A view for showing history
+    History,
+    /// A view for showing in-progress transactions
+    Progress
 };
 
 class ApplicationWindow : public MuonMainWindow
@@ -74,6 +80,7 @@ private:
     ApplicationBackend *m_appBackend;
     QSplitter *m_mainWidget;
     QStackedWidget *m_viewStack;
+    QWidget *m_busyWidget;
     ViewSwitcher *m_viewSwitcher;
     QStandardItemModel *m_viewModel;
     QHash<QModelIndex, QWidget *> m_viewHash;
@@ -81,8 +88,10 @@ private:
     KAction *m_saveSelectionsAction;
     KMessageWidget *m_launcherMessage;
     ApplicationLauncher *m_appLauncher;
+    ProgressView *m_progressView;
+    QStandardItem *m_progressItem;
 
-    QVector<KService *> m_launchableApps;
+    QVector<KService::Ptr> m_launchableApps;
 
 private Q_SLOTS:
     void initGUI();
@@ -104,6 +113,8 @@ private Q_SLOTS:
     void showAppLauncher();
     void onAppLauncherClosed();
     void clearMessageActions();
+    void addProgressItem();
+    void removeProgressItem();
 };
 
 #endif
