@@ -33,6 +33,7 @@
 #include <KFileDialog>
 #include <KMessageBox>
 #include <KProcess>
+#include <KProtocolManager>
 #include <KStandardDirs>
 #include <KVBox>
 #include <Phonon/MediaObject>
@@ -48,7 +49,6 @@ MuonMainWindow::MuonMainWindow()
     , m_backend(0)
     , m_powerInhibitor(0)
     , m_canExit(false)
-    , m_isReloading(false)
     , m_actionsDisabled(false)
 {
 }
@@ -78,6 +78,10 @@ void MuonMainWindow::initObject()
         m_backend->updateXapianIndex();
     }
 
+    if (KProtocolManager::proxyType() == KProtocolManager::ManualProxy) {
+        m_backend->setWorkerProxy(KProtocolManager::proxyFor("http"));
+    }
+
     emit backendReady(m_backend);
 
     m_canExit = true;
@@ -221,9 +225,6 @@ void MuonMainWindow::errorOccurred(QApt::ErrorCode code, const QVariantMap &args
     QString text;
     QString title;
 
-    if (m_isReloading)
-        return;
-
     switch (code) {
     case QApt::InitError: {
         text = i18nc("@label",
