@@ -103,6 +103,8 @@ void MainWindow::initGUI()
             m_managerWidget, SLOT(filterByStatus(QApt::Package::State)));
     connect(m_filterBox, SIGNAL(filterByOrigin(QString)),
             m_managerWidget, SLOT(filterByOrigin(QString)));
+    connect(m_filterBox, SIGNAL(filterByArchitecture(QString)),
+            m_managerWidget, SLOT(filterByArchitecture(QString)));
 
     m_mainWidget->addWidget(m_filterBox);
     m_mainWidget->addWidget(m_managerWidget);
@@ -133,6 +135,7 @@ void MainWindow::initObject()
 void MainWindow::loadSettings()
 {
     m_backend->setUndoRedoCacheSize(MuonSettings::self()->undoStackSize());
+    m_managerWidget->invalidateFilter();
 }
 
 void MainWindow::loadSplitterSizes()
@@ -437,10 +440,7 @@ void MainWindow::reload()
     returnFromPreview();
     m_stack->setCurrentWidget(m_mainWidget);
 
-    m_isReloading = true;
     m_managerWidget->reload();
-    m_isReloading = false;
-
     if (m_reviewWidget) {
         m_reviewWidget->reload();
     }
