@@ -29,7 +29,7 @@
 #include <KAction>
 #include <KActionCollection>
 #include <KDebug>
-#include "kmessagewidget.h"
+#include <KMessageWidget>
 #include <KProcess>
 #include <KStandardDirs>
 #include <Solid/Device>
@@ -234,14 +234,9 @@ void MainWindow::reload()
 
     disconnect(m_updaterWidget, SIGNAL(packageChanged(QApt::Package*)),
                m_changelogWidget, SLOT(setPackage(QApt::Package*)));
-    m_isReloading = false;
-
     m_updaterWidget->reload();
-
     connect(m_updaterWidget, SIGNAL(packageChanged(QApt::Package*)),
             m_changelogWidget, SLOT(setPackage(QApt::Package*)));
-    m_isReloading = true;
-
     m_changelogWidget->setPackage(0);
     QApplication::restoreOverrideCursor();
 
